# Guidelines for Contributing

Thank you for being interested in contributing to PyMC. PyMC is an open source, collective effort, and everyone is welcome to contribute. There are many ways in which you can help make it better. Please check the latest information for contributing to the PyMC project on [this guidelines](https://docs.pymc.io/en/latest/contributing/index.html).

Quick links
-----------

* [Pull request (PR) step-by-step ](https://docs.pymc.io/en/latest/contributing/pr_tutorial.html)
* [Pull request (PR) checklist](https://docs.pymc.io/en/latest/contributing/pr_checklist.html)
* [Python style guide with pre-commit](https://docs.pymc.io/en/latest/contributing/python_style.html)
* [Running the test suite](https://docs.pymc.io/en/latest/contributing/running_the_test_suite.html)
* [Running PyMC in Docker](https://docs.pymc.io/en/latest/contributing/docker_container.html)
* [Submitting a bug report or feature request](https://github.com/pymc-devs/pymc/issues)

For a complete list visit [the contributing section of the documentation](https://docs.pymc.io/en/latest/contributing/index.html).
